/*
    $File$
    Date        Author          Changes
    Nov 21 2000 Richard Jones   Created

    Copyright (c) 2000, Richard Jones
    All rights reserved.
 */

package MetaTF.Generator.Java;

import java.util.Map;
import java.io.*;
import MetaTF.Types;
import MetaTF.Panic;

/**********************************************************************************************
 * Util
 * General utility static methods
 *
 * @version rel-1-2 ($Revision: 1.2 $, $Date: 2000/12/15 16:29:12 $),
 * @author Richard Jones
**/
public class Util {

    
    /**
     * Convert a name to class form
     *
     * @return the class form of the name
    **/
    public static String classify(String s) {
        return firstToUppercase(s, true);
    }

    /**
     * Convert name of a section to an instance form
     *
     * @return the instance form of the section name
    **/
    public static String sectionify(String s) {
        return firstToUppercase(s, false);
    }
    
    /**
     * Convert a name to a member form,
     * handling repeated instances properly
     *
     * @param s the name
     * @param knownFields a Map <name, Integer> of encountered names and
     *                    the suffix to give the next instance of s
     * @return the member form of the name
     */
    public static String declassify(String s, Map knownFields) {
        s = firstToUppercase(s, false);
        if(knownFields.containsKey(s)) {
            int i = ((Integer)knownFields.get(s)).intValue();
            knownFields.put(s, new Integer(i+1));
            return s+i;
        } else {
            knownFields.put(s, new Integer(2));
            return s;
        }
    }

    /** 
     * Change first character of string to uppercase / lowercase
     *
     * @param str the string to be changed
     * @param toUpper if true change first character to uppercase, else to lowercase
    **/
    public static String firstToUppercase(String str, boolean toUpper) {
        StringBuffer s = new StringBuffer(str);
        char c = s.charAt(0);
        c = toUpper ?
                Character.toUpperCase(c) :
                Character.toLowerCase(c);
        s.setCharAt(0,c);
        return s.toString();
    }

    /*
     * Convert a name to a type
     *
     * @return the type form of the name
     */
    public static String typify(String str) {
        if(str==null)
            Panic.panic("Util.typify gets null string");
        if(Types.primitiveType(str))
            return str;
        if(str.equals("index"))
            return "Index";
        if(str.equals("string"))
            return "String";
        return "-- UNKNOWN TYPE please report --";
    }

    /*
     * Convert a name to a reader/writer kind
     * such as Num, Index or String
     *
     * @return the kind form of the name
     */
    public static String kindify(String str) {
        if(str==null)
            Panic.panic("Util.kindify gets null string");
        if(Types.primitiveType(str))
            return "Num";
        if(str.equals("index"))
            return "Index";
        if(str.equals("string"))
            return "String";
        return "-- UNKNOWN TYPE please report --";
    }


    /**
     * Convert a field name to the constant representation for ALL fields of this name
     *
     * @param n the field name
     * @return a constant representation of n
    **/
    public static String constantify(String n) {
        return "ALL_"+n.toUpperCase();
    }
    
    /**
     *Convert field name to a constant field representation
     *
     * @param f the field name
     * @return the constant field representation of t
    **/
    public static String fieldify(String f) {
        return f.toUpperCase();
    }
}

