/*
    $File$
    Date        Author          Changes
    Nov 30 2000 Richard Jones   Created
    
    Copyright (c) 2000, Richard Jones
    All rights reserved.
 */
 
package MetaTF.Runtime;

import MetaTF.MetaTFConstants;
import MetaTF.BadRecordException;
import MetaTF.Panic;
import java.util.List;

/**
 * A TraceField representing a field with index type
 *
 * @version rel-1-2 ($Revision: 1.2 $, $Date: 2001/03/29 15:53:24 $),
 * @author Richard Jones
**/
public class IndexTraceField extends TraceField {                                   

    /** The cached list of records that this field indexes **/
    private List records;                                                     

    /** The current value of this field (if encoding is sectionStride) **/
    private int current;                                                      

    /** The stride (if encoding is sectionStride) **/
    int stride;                                                       
                                                                             
    /**
     * Allocate a new object representing a encoding of a field of index type
     *
     * @param n the name of the field
     * @param it the encoding
     * @param recs the cached list of records that this field indexes into
     * @param st the stride
    **/
    public IndexTraceField(String n, int it, List recs, int st) {            
        super(n);                                                            
        try {                                                                
            setInterpretationType(it);   // SectionStride                    
            if(it!=MetaTFConstants.Default)                                  
                { records = recs; current = 0; stride = st; }                
        } catch(BadRecordException e) {                                      
            Panic.panic("Couldn't create an IndexTraceField for "+n);            
        }                                                                    
    }                                                                        

    /**
     * Allocate a new object representing a encoding of a field of index type
     *
     * @param n the name of the field
     * @param it the encoding
     * @param recs the cached list of records that this field indexes into
    **/
    public IndexTraceField(String n, int it, List recs) {                    
        this(n, it, recs, 0);                                                
    }                                                                        

    void setInterpretationType(int i) throws BadRecordException {         
        if(!(i==MetaTFConstants.SectionOffset || i==MetaTFConstants.SectionStride || i==MetaTFConstants.Default))  
            throw new BadRecordException("Cannot set an encoding other than default 0, sectionOffset or sectionStride in an IndexTraceField"); 
        encodingType = i;                                              
    }                                                                        

    void setValue(long v) throws BadRecordException {                 
        current = (int) v;                                                   
    }                                                                        

    void setValue(String v) throws BadRecordException {               
        throw new BadRecordException("Attempt to change values for index type ignored"); 
    }                                                                        

    void setValue2(long v) throws BadRecordException {                
        throw new BadRecordException("Attempt to change values for index type ignored"); 
    }                                                                        

    long getValue() {                                                 
        return current;                                                      
    }                                                                        

    int getValue2() {                                                 
        if(!(encodingType==MetaTFConstants.Default))                   
            return stride;                                                   
        else {                                                               
            Panic.panic("Cannot getValue2 of index field with encoding default"); 
            return 0; //NEVER REACHED                                        
        }                                                                    
    }                                                                        

    public List getRecords () { return records; }                            
}                                                                            

