/*
    $File$
    Date        Author          Changes
    Nov 21 2000 Richard Jones   Created
    
    Copyright (c) 2000, Richard Jones
    All rights reserved.
 */
 
package MetaTF.Runtime;

import MetaTF.BadRecordException;
import java.io.IOException;

/**
 * LowLevelReader interface
 *
 * @version rel-1-2 ($Revision: 1.2 $, $Date: 2001/03/29 15:53:24 $),
 * @author Richard Jones
**/
public interface LowLevelReader {

    /**
     * Read a number
     *
     * @exception BadRecordException IF the record is malformed
     * @exception IOException IF the read fails
    **/
    public long   readNum()    throws BadRecordException, IOException;

    /**
     * Read a tag
     *
     * @exception BadRecordException IF the record is malformed
     * @exception IOException IF the read fails
    **/
    public int    readTag()    throws BadRecordException, IOException;

    /**
     * Read a string
     * Handles escape characters etc.
     *
     * @exception BadRecordException IF the record is malformed
     * @exception IOException IF the read fails
    **/
    public String readString() throws BadRecordException, IOException;

    /**
     * Read a special
     * read without encoding
     *
     * @exception BadRecordException IF the record is malformed
     * @exception IOException IF the read fails
    **/
    public String readAny() throws BadRecordException, IOException;

    /**
     * Read to end of line without encoding.
     * Used for comments
     *
     * @exception BadRecordException IF the record is malformed
     * @exception IOException IF the read fails
    **/    
    public String readln() throws BadRecordException, IOException;
}
