/*
    $File$
    Date        Author          Changes
    Nov 30 2000 Richard Jones   Created
    
    Copyright (c) 2000, Richard Jones
    All rights reserved.
 */
 
package MetaTF.Runtime;

import MetaTF.MetaTFConstants;
import MetaTF.BadRecordException;
import MetaTF.Panic;
import java.util.List;

/**
 * A TraceField representing a field with string type
 *
 * @version rel-1-2 ($Revision: 1.2 $, $Date: 2001/03/29 15:53:24 $),
 * @author Richard Jones
**/
public class StringTraceField extends TraceField {

    /** The value of the string **/
    public String defaultValue;                                              
                                                                             
    /**
     * Allocate a new object representing a encoding of a field of string type
     *
     * @param n the name of the field
     * @param it the encoding
     * @param i the string
     * @param zero always ignored
    **/
    public StringTraceField(String n, int it, String i, long zero) {          
        super(n);                                                            
        try {                                                                
            setInterpretationType(it);   // None or Default                  
            defaultValue = i;                                                
        } catch(BadRecordException e) {                                      
            Panic.panic("Couldn't create a StringTraceField for "+n);            
        }                                                                    
    }                                                                        

    /**
     * Allocate a new object representing a encoding of a field of string type
     *
     * @param n the name of the field
     * @param it the encoding
     * @param i the string
    **/
    public StringTraceField(String n, int it, String i) {          
        this(n, it, i, 0);                                                   
    }                                                                        

    /**
     * Allocate a new object representing a encoding of a field of string type
     *
     * @param n the name of the field
     * @param it the encoding
    **/
    public StringTraceField(String n, int it) {          
        this(n, it, null, 0);                                                   
    }                                                                        

    public void setInterpretationType(int i) throws BadRecordException {         
        if(!(i==MetaTFConstants.None || i==MetaTFConstants.Default))         
            throw new BadRecordException("cannot set an encoding other than None or Default in a StringTraceField"); 
        encodingType = i;                                              
    }                                                                        

    void setValue(long v) throws BadRecordException {                 
        throw new BadRecordException("tried to set a numeric default value for a string"); 
    }                                                                        

    void setValue(String v) throws BadRecordException {               
        defaultValue = v;                                                    
    }                                                                        

    void setValue2(long v)  throws BadRecordException {               
        throw new BadRecordException("tried to set a numeric default value for a string");  
    }                                                                        

    String getValue() {                                               
        if(encodingType != MetaTFConstants.None)                       
            return defaultValue;                                             
        else {                                                               
            Panic.panic("Cannot getValue of field with encoding none");    
            return null; //NEVER REACHED                                     
        }                                                                    
    }                                                                        
}                                                                            

